summaryrefslogtreecommitdiffstats
path: root/hl/examples/ex_table_10.c
diff options
context:
space:
mode:
Diffstat (limited to 'hl/examples/ex_table_10.c')
-rw-r--r--hl/examples/ex_table_10.c5
1 files changed, 4 insertions, 1 deletions
diff --git a/hl/examples/ex_table_10.c b/hl/examples/ex_table_10.c
index c4df6fe3..fb11a98 100644
--- a/hl/examples/ex_table_10.c
+++ b/hl/examples/ex_table_10.c
@@ -127,7 +127,10 @@ int main( void )
printf ("\n");
}
- /* Close the file */
+ /* close type */
+ H5Tclose( string_type );
+
+ /* close the file */
H5Fclose( file_id );
return 0;